pub(crate) fn convolve_y(
src: &Pixmap,
dst: &mut Pixmap,
src_width: u16,
src_height: u16,
kernel: &[f32],
radius: u8,
edge_mode: EdgeMode,
)Expand description
Apply vertical blur pass (1D convolution along y-axis).
For each output pixel, computes a weighted sum of vertically neighboring pixels using the Gaussian kernel. Handles edge cases according to the specified edge mode. Writes results to a destination buffer to avoid overwriting source data.